@@ -6,6 +6,7 @@ import logging
 import os
 import requests
 import threading
+import pkg_resources
 
 from datetime import datetime, timedelta
 from redo import retrier
@@ -54,6 +55,7 @@ class Panoptes(object):
     _http_headers = {
         'default': {
             'Accept': 'application/vnd.api+json; version=1',
+            'User-Agent': 'panoptes-python-client/version=' + pkg_resources.require('panoptes_client')[0].version
         },
         'GET': {},
         'PUT': {
@@ -526,7 +528,7 @@ class Panoptes(object):
                 grant_type = 'client_credentials'
 
             if not self.logged_in:
-                if grant_type is 'password':
+                if grant_type == 'password':
                     if not self.login():
                         return
 
@@ -706,7 +708,7 @@ class PanoptesObject(object):
         try:
             if (
                 name not in PanoptesObject.RESERVED_ATTRIBUTES
-                and name is not 'id'
+                and name != 'id'
                 and not self._loaded
             ):
                 self.reload()
